""" 
This module was created to handle classification 
models such as Logistic Regression, Linear Discriminant Analysis, 
Quadratic Discriminant Analysis, Naive Bayes and Support Vector Machine.

"""


class LogisticRegression:
    pass

    
class LinearDiscriminantAnalysis:
    pass


class QuadraticDiscriminantAnalysis:
    pass


class NaiveBayes:
    pass


class SupportVectorMachines:
    
    def one_versus_one():
        """Classification using SVM with more than two classes.
        """
        pass
    
    def one_versus_all  ():
        """Classification using SVM with more than two classes.
        """
        pass
