""" 
This module was created to handle some 
of the Dimension Reduction methods.

"""


def pca():
    """Principal Components Analysis
    """
    pass


def pcr():
    """Principal Components Regression
    """
    pass


def partial_least_square():
    pass