""" 
This module was created to handle non-linear
models such as Bagging, Random Forests, Boosting, and
Bayesian Additive Regression Trees.

"""


class Bagging:
    
    def out_of_bag():
        """Out-of-Bag (OOB) error estimation"""
        pass

    
class RandomForest:
    
    def out_of_bag():
        """Out-of-Bag (OOB) error estimation"""
        pass


class Boosting:
    pass


class BayesianAdditiveRegressionTrees:
    pass

