""" 
This module was created to handle Unsupervised 
Learning methods. 

"""


class PrincipalComponentsAnalysis:
    pass


class KMeans:
    """Numerical clustering
    """
    pass


class KMode:
    """Categorical clustering
    """
    pass


class KPrototype:
    """Numerical and Categorical clustering
    """
    pass


class HierarchicalClustering:
    pass