""" 
This module was created to handle some 
of the Shrinkage methods.

"""


def ridge_regression():
    pass


def the_lasso():
    pass


def selecting_tuning_parameter():
    """Get best tuning parameter for Ridge Regression 
    and Lasso procedures.
    
    Implementing ridge regression and 
    the lasso requires a method for selecting 
    a value for the tuning parameter λ.
    """
    pass