""" 
This module was created to handle some 
of the Subset Selection methods.

"""


def best_subset_selection():
    pass


def forward_stepwise_selection():
    pass


def backward_stepwise_selection():
    pass


def hybrid_stepwise_selection():
    pass


def one_standard_error_rule():
    """We first calculate the standard error of the 
    estimated test MSE for each model size, and then select 
    the smallest model for which the estimated test error 
    is within one standard error of the lowest point on the curve.
    """
    pass