""" 
This module was created to handle some 
of the Test Error Estimation methods.

"""


def cp():
    """Mallow's Cp method.
    """
    pass


def aic():
    """Akaike information criterion (AIC).
    """
    pass


def bic():
    """Bayesian information criterion (BIC).
    """
    pass


def adjusted_r2():
    """Adjusted R^2.
    """
    pass